@@ -95,7 +95,7 @@ class MarkdownParser(BisonParser):
         %option extra-type="int"
 
         %{
-        #include "tokens.h"
+        #include "tmp.tab.h"
 
         // chars to replace
         const char *chr_sqr_open = (char *)"[\0";
@@ -172,7 +172,7 @@ class MarkdownParser(BisonParser):
         #include <stdio.h>
         #include <string.h>
         #include "Python.h"
-        #include "tokens.h"
+        #include "tmp.tab.h"
         extern void *py_parser;
         extern void (*py_input)(PyObject *parser, char *buf, int *result, int max_size);
 
@@ -249,7 +249,7 @@ class MarkdownParser(BisonParser):
         "\\"{word}(\.{word})*"{"{whitespace_nl}            { STATE_PUSH(ATTRIBUTE_STATE); returntoken(LATEX_COMMAND_WITH_OPTIONAL_ARGUMENT); }
 
         {whitespace}"|"{whitespace}             { returntoken(TABLE_DELIM); }
-        {whitespace}[-+]{3,}{whitespace}        { returntoken(TABLE_HRULE); }
+        {whitespace}([-]{3,}|[+]{3,}){whitespace}        { returntoken(TABLE_HRULE); }
         {whitespace}:---+{whitespace}           { returntoken(TABLE_HRULE_LEFT_ALIGNED); }
         {whitespace}:---+:{whitespace}          { returntoken(TABLE_HRULE_CENTERED); }
         {whitespace}---+:{whitespace}           { returntoken(TABLE_HRULE_RIGHT_ALIGNED); }
@@ -286,7 +286,7 @@ class MarkdownParser(BisonParser):
         <INITIAL>^{whitespace}"{"               { STATE_PUSH(ATTRIBUTE_STATE); returntoken(ATTR_START); }
         <INITIAL>"{"                            { STATE_PUSH(ATTRIBUTE_STATE); returntoken(ATTR_START); }
         <ATTRIBUTE_STATE>"{"                    { STATE_PUSH(ATTRIBUTE_STATE); returntoken(ATTR_START); }
-        <ATTRIBUTE_STATE>{whitespace_nl}"}"{whitespace}        { STATE_POP(); returntoken(ATTR_END); }
+        <ATTRIBUTE_STATE>{whitespace_nl}"}"     { STATE_POP(); returntoken(ATTR_END); }
         <ATTRIBUTE_STATE>"}["                   { STATE_POP(); returntoken(ATTR_END_AND_ARG_START); }
         <ATTRIBUTE_STATE>"["                    { STATE_PUSH(INITIAL); returntoken(ATTR_INPUT); }
         <ATTRIBUTE_STATE>"#"                    { returntoken(ATTR_HASH); }
@@ -348,9 +348,9 @@ class MarkdownParser(BisonParser):
         \n{indent}*===+/\n                      { returntoken(HEADING_ULINEDBL); }
         \n{indent}*---+/\n                      { returntoken(HEADING_ULINESGL); }
         ^{indent}*[\*\-\+]" "{whitespace}       { returntoken(ULIST_SYM); }
-        ^{indent}*[\*\-\+]\[[a-zA-Z\-\_\?]+\]" "{whitespace}        { returntoken(ULIST_SYM); }
-        ^{indent}*[\*\-\+]\[{whitespace}*\]" "{whitespace}        { returntoken(ULIST_SYM); }
-        ^{indent}*[\*\-\+]\[{utf_8}\]" "{whitespace}        { returntoken(ULIST_SYM); }
+        ^{indent}*[\*\-\+]{whitespace}\[[a-zA-Z\-\_\?]+\]" "{whitespace}        { returntoken(ULIST_SYM); }
+        ^{indent}*[\*\-\+]{whitespace}\[{whitespace}*\]" "{whitespace}        { returntoken(ULIST_SYM); }
+        ^{indent}*[\*\-\+]{whitespace}\[{utf_8}\]" "{whitespace}        { returntoken(ULIST_SYM); }
         ^{indent}*[ivxlcdmlIVXLCDML0-9]+". "{whitespace}          { returntoken(OLIST_SYM); }
         ^{indent}*[a-zA-Z]". "{whitespace}      { returntoken(OLIST_SYM); }
         ^{indent}*"> "{whitespace}              { returntoken(QUOTE_SYM); }
@@ -486,7 +486,7 @@ class MarkdownParser(BisonParser):
 
     @staticmethod
     def ulist_sym_get(s):
-        s = s.strip()
+        s = ''.join(s.split())
         if len(s) >= 2 and s[1] == "[":
             s = s[2:-1]
         return s
